@@ -2,9 +2,9 @@
 import inspect
 import logging
 import os.path
-import re
-import time
 import sys
+import time
+
 import colorlog
 
 MY_LOG_INFO = logging.INFO
@@ -27,18 +27,24 @@ class mylog(object):
                stream_log_level：控制台日志级别
                save_log2_file:是否需要保存至日志文件，默认是FALSE，如果为TRUE，则log_path不能为空
                is_only_file:日志只保存至日志文件，不在控制台输出，该参数主要用在进度条模块中，设置进度条保存在日志文件中时，需要设置该参数为True，保证不在控制台输出日志进度而保存到文件
+               is_split_log:是否按照日期分割日志文件，默认为False，如果设置为True，则会按照每天的日期产生文件夹和日志文件
+               is_all_file:生成日志文件时是否产生全部日志文件，默认为False，此时只产生一个日志文件，设置为True，则会产生不同级别的日志文件
+               log_file_name:日志文件名称，默认为log
         """
 
         self.__log_level = kwargs.get('log_level', MY_LOG_INFO)
         self.__file_log_level = kwargs.get('file_log_level', None)
         self.__stream_log_level = kwargs.get('stream_log_level', None)
-        self.__save_log2_file = kwargs.get('save_log2_file', None)
+        self.__save_log2_file = kwargs.get('save_log2_file', False)
         self.__log_name = kwargs.get('log_name', 'log')
+        self.__is_split_log = kwargs.get('is_split_log', False)
+        self.__is_all_file = kwargs.get('is_all_file', False)
+        self.__log_file_name = kwargs.get('log_file_name', 'log')
         # 设置日志路径
         self.__log_path = kwargs.get('log_path', None)
 
         # 只需要保存到文件，不需要在控制台输出,默认是FALSE
-        self.is_only_file = kwargs.get('is_only_file', None)
+        self.is_only_file = kwargs.get('is_only_file', False)
 
         # 不同级别的日志颜色
         # 以下转义码可用于格式字符串：
@@ -75,6 +81,7 @@ class mylog(object):
         self.__logger.setLevel(self.__log_level)
 
         # 设置一些变量
+        self.__one_log_name = None
         self.__all_log_name = None
         self.__info_log_name = None
         self.__error_log_name = None
@@ -87,6 +94,7 @@ class mylog(object):
         self.__debug_file_handler = None
         self.__warn_file_handler = None
         self.__stream_handler = None
+        self.__one_file_handler = None
 
         # 设置formatter
         # __format_str = 'time:%(asctime)s -log_name:%(name)s -level:%(levelname)-s -file_name:%(filename)-8s -fun_name:%(funcName)s -chain:%(chain)s - %(lineno)d line -message: %(message)s'
@@ -126,15 +134,19 @@ class mylog(object):
         # 如果不存在已经设置日志路径
         if self.__log_path is None:
             # os.getcwd()获取当前文件的路径，此时日志保存在当前工具类下log目录下，不建议不指定日志文件目录
-            path_dir = os.path.dirname(__file__) + '/log' + '/' + self.__log_day
+            path_dir = os.path.dirname(__file__) + '/log'
+            if self.__is_split_log is True:
+                path_dir = path_dir + '/' + self.__log_day
             # 如果该项目下没有log目录，创建log目录
             if not os.path.exists(path_dir):
                 os.makedirs(path_dir)
             # os.path.dirname()获取指定文件路径的上级路径
-            log_path = os.path.abspath(os.path.dirname(path_dir)) + '/log'
+            # log_path = os.path.abspath(os.path.dirname(path_dir)) + '/log'
         else:
             # 否则，设置了路径就使用用户设置的路径
-            path_dir = self.__log_path + '/' + self.__log_day
+            path_dir = self.__log_path
+            if self.__is_split_log is True:
+                path_dir = path_dir + '/' + self.__log_day
             # 最后为目录，不存在则创建
             if not os.path.exists(path_dir):
                 os.makedirs(path_dir)
@@ -142,66 +154,113 @@ class mylog(object):
         # 创建日志名称。
         # rq = time.strftime('%Y-%m-%d', time.localtime(time.time()))
         # 拼接日志文件路径名称
-        self.__all_log_name = os.path.join(path_dir, self.__log_day + '-' + 'ALL' + '.log')
-        self.__info_log_name = os.path.join(path_dir, self.__log_day + '-' + str(logging.getLevelName(MY_LOG_INFO)) + '.log')
-        self.__error_log_name = os.path.join(path_dir, self.__log_day + '-' + str(logging.getLevelName(MY_LOG_ERROR)) + '.log')
-        self.__debug_log_name = os.path.join(path_dir, self.__log_day + '-' + str(logging.getLevelName(MY_LOG_DEBUG)) + '.log')
-        self.__warn_log_name = os.path.join(path_dir, self.__log_day + '-' + str(logging.getLevelName(MY_LOG_WARN)) + '.log')
+        # 如果需要生成全部日志文件并且需要按照日期分割
+        if self.__is_all_file is True and self.__is_split_log is True:
+            self.__all_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '_' + 'all' + '.log')
+            self.__info_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_INFO)).lower() + '.log')
+            self.__error_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_ERROR)).lower() + '.log')
+            self.__debug_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_DEBUG)).lower() + '.log')
+            self.__warn_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_WARN)).lower() + '.log')
+        #     如果需要生成全部日志文件，但是不按照日期分割
+        elif self.__is_all_file is True and self.__is_split_log is False:
+            self.__all_log_name = os.path.join(path_dir, self.__log_file_name + '_' + 'all' + '.log')
+            self.__info_log_name = os.path.join(path_dir, self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_INFO)).lower() + '.log')
+            self.__error_log_name = os.path.join(path_dir, self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_ERROR)).lower() + '.log')
+            self.__debug_log_name = os.path.join(path_dir, self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_DEBUG)).lower() + '.log')
+            self.__warn_log_name = os.path.join(path_dir, self.__log_file_name + '_' + str(logging.getLevelName(MY_LOG_WARN)).lower() + '.log')
+        #     如果不需要生成全部日志文件，但是需要按照日期分割,此时只需要生成设置的日志级别的日志文件即可
+        elif self.__is_all_file is False and self.__is_split_log is True:
+            if self.__log_level == MY_LOG_INFO:
+                self.__info_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '.log')
+            elif self.__log_level == MY_LOG_ERROR:
+                self.__error_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '.log')
+            elif self.__log_level == MY_LOG_DEBUG:
+                self.__debug_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '.log')
+            elif self.__log_level == MY_LOG_WARN:
+                self.__warn_log_name = os.path.join(path_dir, self.__log_day + '_' + self.__log_file_name + '.log')
+            else:
+                raise Exception('Thr log level is not in [info,warn,error,debug]')
+        # 如果既不需要生成所有的日志文件，也不需要按照日期分割，那么则只需要按照当前日志级别生成一个名称不带日期的日志文件
+        elif self.__is_all_file is False and self.__is_split_log is False:
+            self.__one_log_name = os.path.join(path_dir, self.__log_file_name + '.log')
+        else:
+            raise Exception('The is_all_file or is_split_log args error!')
 
     def __set_file_handler(self):
         # CRITICAL = FATAL > ERROR > WARNING =  WARN > INFO > DEBUG > NOTSET = 0
         # 创建一个通用的handler，用于写入日志文件，写入所有的日志级别
-        self.__all_file_handler = logging.FileHandler(self.__all_log_name, encoding='utf-8')
-        self.__all_file_handler.setLevel(self.__file_log_level)
+        if self.__all_log_name is not None:
+            self.__all_file_handler = logging.FileHandler(self.__all_log_name, encoding='utf-8')
+            self.__all_file_handler.setLevel(self.__file_log_level)
         # 创建一个info_handler，用于写入INFO日志文件，只写入info级别及以下的日志
-        self.__info_file_handler = logging.FileHandler(self.__info_log_name, encoding='utf-8')
-        self.__info_file_handler.setLevel(MY_LOG_INFO)
+        if self.__info_log_name is not None:
+            self.__info_file_handler = logging.FileHandler(self.__info_log_name, encoding='utf-8')
+            self.__info_file_handler.setLevel(MY_LOG_INFO)
         # 创建一个error_handler，用于写入ERROR日志文件，只写入error级别及以下的日志
-        self.__error_file_handler = logging.FileHandler(self.__error_log_name, encoding='utf-8')
-        self.__error_file_handler.setLevel(MY_LOG_ERROR)
+        if self.__error_log_name is not None:
+            self.__error_file_handler = logging.FileHandler(self.__error_log_name, encoding='utf-8')
+            self.__error_file_handler.setLevel(MY_LOG_ERROR)
         # 创建一个debug_handler，用于写入DEBUG日志文件，写入debug级别及以下的日志
-        self.__debug_file_handler = logging.FileHandler(self.__debug_log_name, encoding='utf-8')
-        self.__debug_file_handler.setLevel(MY_LOG_DEBUG)
+        if self.__debug_log_name is not None:
+            self.__debug_file_handler = logging.FileHandler(self.__debug_log_name, encoding='utf-8')
+            self.__debug_file_handler.setLevel(MY_LOG_DEBUG)
         # 创建一个warn_handler，用于写入WARNING日志文件，写入WARNING级别及以下的日志
-        self.__warn_file_handler = logging.FileHandler(self.__warn_log_name, encoding='utf-8')
-        self.__warn_file_handler.setLevel(MY_LOG_WARN)
+        if self.__warn_log_name is not None:
+            self.__warn_file_handler = logging.FileHandler(self.__warn_log_name, encoding='utf-8')
+            self.__warn_file_handler.setLevel(MY_LOG_WARN)
+        #     创建一个one_handler，用于写入log_level日志文件
+        if self.__one_log_name is not None:
+            self.__one_file_handler = logging.FileHandler(self.__one_log_name, encoding='utf-8')
+            self.__one_file_handler.setLevel(self.__log_level)
 
     def __set_file_formatter(self):
         # 日志文件日志格式
-        self.__all_file_handler.setFormatter(self.__formatter)
+        if self.__all_file_handler is not None:
+            self.__all_file_handler.setFormatter(self.__formatter)
         # 日志文件日志格式
-        self.__info_file_handler.setFormatter(self.__formatter)
+        if self.__info_file_handler is not None:
+            self.__info_file_handler.setFormatter(self.__formatter)
         # 日志文件日志格式
-        self.__error_file_handler.setFormatter(self.__formatter)
+        if self.__error_file_handler is not None:
+            self.__error_file_handler.setFormatter(self.__formatter)
         # 日志文件日志格式
-        self.__debug_file_handler.setFormatter(self.__formatter)
+        if self.__debug_file_handler is not None:
+            self.__debug_file_handler.setFormatter(self.__formatter)
         # 日志文件日志格式
-        self.__warn_file_handler.setFormatter(self.__formatter)
+        if self.__warn_file_handler is not None:
+            self.__warn_file_handler.setFormatter(self.__formatter)
+        # 日志文件日志格式
+        if self.__one_file_handler is not None:
+            self.__one_file_handler.setFormatter(self.__formatter)
 
     def __add_file_handler(self):
         # if not self.__logger.handlers:
         # 给logger添加handler
         # 如果保存到文件
-        if not (self.__all_file_handler in self.__logger.handlers):
+        if not (self.__all_file_handler in self.__logger.handlers) and self.__all_file_handler is not None:
             # 所有日志级别handler，如果不配置，则无法写入文件
             self.__logger.addHandler(self.__all_file_handler)
 
-        if not (self.__info_file_handler in self.__logger.handlers):
+        if not (self.__info_file_handler in self.__logger.handlers) and self.__info_file_handler is not None:
             # info日志级别handler，如果不配置，则无法写入文件
             self.__logger.addHandler(self.__info_file_handler)
 
-        if not (self.__error_file_handler in self.__logger.handlers):
+        if not (self.__error_file_handler in self.__logger.handlers) and self.__error_file_handler is not None:
             # error日志级别handler，如果不配置，则无法写入文件
             self.__logger.addHandler(self.__error_file_handler)
 
-        if not (self.__debug_file_handler in self.__logger.handlers):
+        if not (self.__debug_file_handler in self.__logger.handlers) and self.__debug_file_handler is not None:
             # debug日志级别handler，如果不配置，则无法写入文件
             self.__logger.addHandler(self.__debug_file_handler)
 
-        if not (self.__warn_file_handler in self.__logger.handlers):
+        if not (self.__warn_file_handler in self.__logger.handlers) and self.__warn_file_handler is not None:
             # warning日志级别handler，如果不配置，则无法写入文件
             self.__logger.addHandler(self.__warn_file_handler)
 
+        if not (self.__one_file_handler in self.__logger.handlers) and self.__one_file_handler is not None:
+            # 不按照日期分割和不需要生成所有日志文件，如果不配置，则无法写入文件
+            self.__logger.addHandler(self.__one_file_handler)
+
     def get_logger(self):
         if self.__save_log2_file is True or self.is_only_file is True:
             self.__set_log_file_name()
@@ -257,19 +316,51 @@ __self_my_log = None
 __myLogger = None
 
 
-def get_log(log_name='self_my_log', log_path=None, log_level=None, file_log_level=None,
-            stream_log_level=None, save_log2_file=False, is_only_file=False):
+def get_log(log_name='self_my_log',
+            log_path=None,
+            log_level=None,
+            file_log_level=None,
+            stream_log_level=None,
+            save_log2_file=False,
+            is_only_file=False,
+            is_split_log=False,
+            is_all_file=False,
+            log_file_name='log'):
     global __self_my_log
-    __self_my_log = mylog(log_name=log_name, log_path=log_path, log_level=log_level, file_log_level=file_log_level,
-                          stream_log_level=stream_log_level, save_log2_file=save_log2_file, is_only_file=is_only_file)
+    __self_my_log = mylog(log_name=log_name,
+                          log_path=log_path,
+                          log_level=log_level,
+                          file_log_level=file_log_level,
+                          stream_log_level=stream_log_level,
+                          save_log2_file=save_log2_file,
+                          is_only_file=is_only_file,
+                          is_split_log=is_split_log,
+                          is_all_file=is_all_file,
+                          log_file_name=log_file_name)
     return __self_my_log
 
 
-def getLogger(log_name='self_my_log', log_path=None, log_level=None, file_log_level=None,
-              stream_log_level=None, save_log2_file=False, is_only_file=False):
+def getLogger(log_name='self_my_log',
+              log_path=None,
+              log_level=None,
+              file_log_level=None,
+              stream_log_level=None,
+              save_log2_file=False,
+              is_only_file=False,
+              is_split_log=False,
+              is_all_file=False,
+              log_file_name='log'):
     global __self_my_log
-    __self_my_log = get_log(log_name=log_name, log_path=log_path, log_level=log_level, file_log_level=file_log_level,
-                            stream_log_level=stream_log_level, save_log2_file=save_log2_file, is_only_file=is_only_file)
+    __self_my_log = get_log(log_name=log_name,
+                            log_path=log_path,
+                            log_level=log_level,
+                            file_log_level=file_log_level,
+                            stream_log_level=stream_log_level,
+                            save_log2_file=save_log2_file,
+                            is_only_file=is_only_file,
+                            is_split_log=is_split_log,
+                            is_all_file=is_all_file,
+                            log_file_name=log_file_name)
     if __self_my_log is None:
         raise Exception('The global self_my_log is none,please set self_my_log')
 
